@@ -14,7 +14,7 @@ from shutil import copy2
 from email.utils import formatdate
 from enum import Enum
 
-__version__ = '2.202205'
+__version__ = '2.202301'
 __dhlib__ = '/usr/share/debhelper/dh_make'
 policy_version = '4.6.2'
 
@@ -83,7 +83,7 @@ def process_dir(args, subs_func, adir, destdir='', root=''):
 
         if os.path.isdir(file):
             if not os.path.exists(dest):
-                os.mkdir(dest, 0o755)
+                os.makedirs(dest, 0o755, exist_ok=True)
             process_dir(args, subs_func, file, dest, root)
         else:
             process_file(args, subs_func, file, dest)
